# Remote Screen Capture/Share

<badges>[![version](https://img.shields.io/pypi/v/remotescreen.svg)](https://pypi.org/project/remotescreen/)
[![license](https://img.shields.io/pypi/l/remotescreen.svg)](https://pypi.org/project/remotescreen/)
[![pyversions](https://img.shields.io/pypi/pyversions/remotescreen.svg)](https://pypi.org/project/remotescreen/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>View remote screen via HTTP/HTTPS.</i>

# Hierarchy

```
remotescreen
```

# Example

## python
```python

```
